Hud class
Our main Hud class.
Constructors
- Hud()
Properties
- animationDuration ↔ Duration
-
The duration used for built-in animations.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVisible → bool
-
Property that let's us determine if this Hud is currently visible.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hide(
{bool animated = true}) → void -
Hide this Hud, optionally with an
animatedfade-out. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required BuildContext context, required Widget child, HudPosition position = HudPosition.custom, Duration? duration, bool isBlocking = false, Color? backgroundColor = Colors.transparent, Color? hudColor, BoxDecoration? hudDecoration, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Hud -
Main method to display this Hud. A
contextandchildwidget are required. You can optionally set abackgroundColorto perhaps dim the screen behind the hud. Set ahudColororhudDecorationto customize the background of the Hud itself. Thedurationindicates how long the Hud should be visible before it auto-hides, if you omit this, the Hud will remain on screen until you dismiss it by calling hide().isBlockingdetermines whether the background of the overlay prevents user interaction with elements behind it. The Hud itself always blocks elements underneath it, meaning a fullscreen overlay will block regardless of this setting. Set thepositionparameter to a HudPosition value to determine where the Hud will be laid out. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultDarkHudDecoration ↔ BoxDecoration
-
A preset decoration that can be used Huds, dark version intended to have
light content.
getter/setter pair
- defaultLightHudDecoration ↔ BoxDecoration
-
A preset decoration that can be used Huds, light version intended to have
dark content.
getter/setter pair